#[repr(transparent)]pub struct QRCode {
inner: TypedObjectRef<QRCode, <QRCode as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A widget that display a QR Code.
The QR code of QRCode is set with the QRCode::set_bytes()
method. It is recommended for a QR Code to have a quiet zone, in most
contexts, widgets already count with such a margin.
The code can be themed via css, where a recommended quiet-zone can be as a padding:
qrcode {
color: black;
background: white;
padding: 24px; /* 4 ⨉ block-size */
}GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<QRCode, <QRCode as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl QRCode
impl QRCode
Sourcepub fn block_size(&self) -> <Cell<u32> as Property>::Value
pub fn block_size(&self) -> <Cell<u32> as Property>::Value
The block size of this QR Code.
Determines the size of the widget.
Sourcepub fn set_block_size<'a>(
&self,
value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_block_size<'a>( &self, value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>, )
The block size of this QR Code.
Determines the size of the widget.
Sourcepub fn connect_block_size_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_block_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the block-size property
Sourcepub fn notify_block_size(&self)
pub fn notify_block_size(&self)
Notify listeners of a change in the block-size property
Sourceimpl QRCode
impl QRCode
Sourcepub fn from_bytes(bytes: &[u8]) -> Self
pub fn from_bytes(bytes: &[u8]) -> Self
Creates a new QRCode with a QR code generated from bytes.
Sourcepub fn set_bytes(&self, bytes: &[u8])
pub fn set_bytes(&self, bytes: &[u8])
Sets the displayed code of self to a QR code generated from bytes.
Sourcepub fn set_qrcode(&self, qrcode: QrCode)
pub fn set_qrcode(&self, qrcode: QrCode)
Set the QrCode to be displayed.